@@ -1,13 +1,15 @@
 # Generate GraphQL queries for queries pertaining to media objects.
+from typing import Union
+
 from trompace.exceptions import UnsupportedLanguageException, NotAMimeTypeException
 from trompace.queries.templates import format_query
-from trompace import StringConstant, _Neo4jDate, filter_none_args, docstring_interpolate
+from trompace import StringConstant, _Neo4jDate, filter_none_args, docstring_interpolate, make_filter
 from trompace.constants import SUPPORTED_LANGUAGES
 
 
 def query_mediaobject(identifier: str = None, creator: str = None, contributor: str = None,
-                      encodingformat: str = None, source: str = None, contenturl: str = None, inlanguage:str = None,
-                      return_items: list = None):
+                      encodingformat: str = None, source: str = None, contenturl: str = None, inlanguage: str = None,
+                      filter_: dict = None, return_items: Union[list, str] = None):
 
     """Returns a query for querying the database for a media object.
     Arguments:
@@ -19,7 +21,8 @@ def query_mediaobject(identifier: str = None, creator: str = None, contributor:
         source: The URL of the web resource to be represented by the node.
         contenturl: The URL of the content encoded by the media object.
         inlanguage: The language of the media object. Currently supported languages are en,es,ca,nl,de,fr.
-        return_items: A list of item fields that the query must return.
+        filter_: return nodes with this custom filter
+        return_items: return these items in the response
     Returns:
         The string for the quereing the media object.
     Raises:
@@ -38,6 +41,8 @@ def query_mediaobject(identifier: str = None, creator: str = None, contributor:
         "contentUrl": contenturl,
         "inLanguage": inlanguage
     }
+    if filter_:
+        args["filter"] = StringConstant(make_filter(filter_))
 
     args = filter_none_args(args)
 
